@@ -291,11 +291,13 @@ class NativeView extends SurfaceView
   /**
    * Loads the specified bitmap resource as OpenGL texture.
    *
+   * @param alpha expect a GL_ALPHA texture?
    * @param result an array of 5 integers: texture id, width, height,
    * allocated width, allocated height (all output)
    * @return true on success
    */
-  private boolean loadResourceTexture(String name, int[] result) {
+  private boolean loadResourceTexture(String name, boolean alpha,
+                                      int[] result) {
     /* find the resource */
     int resourceId = resources.getIdentifier(name, "drawable", "org.xcsoar");
     if (resourceId == 0) {
@@ -311,7 +313,7 @@ class NativeView extends SurfaceView
 
     Bitmap bmp = BitmapFactory.decodeResource(resources, resourceId, opts);
 
-    return BitmapUtil.bitmapToOpenGL(bmp, result);
+    return BitmapUtil.bitmapToOpenGL(bmp, alpha, result);
   }
 
   /**
@@ -328,7 +330,7 @@ class NativeView extends SurfaceView
 
     Bitmap bmp = BitmapFactory.decodeFile(pathName, opts);
 
-    return BitmapUtil.bitmapToOpenGL(bmp, result);
+    return BitmapUtil.bitmapToOpenGL(bmp, false, result);
   }
 
   /**
