@@ -26,20 +26,16 @@ Copyright_License {
 #include "Widget/ListWidget.hpp"
 #include "Profile/Profile.hpp"
 #include "Profile/AirspaceConfig.hpp"
-#include "Profile/ProfileKeys.hpp"
 #include "Screen/Canvas.hpp"
 #include "Screen/Features.hpp"
 #include "Screen/Layout.hpp"
 #include "MainWindow.hpp"
 #include "UIGlobals.hpp"
 #include "Look/Look.hpp"
-#include "Look/Fonts.hpp"
-#include "Airspace/ProtectedAirspaceWarningManager.hpp"
+#include "Look/GlobalFonts.hpp"
 #include "Airspace/AirspaceClass.hpp"
 #include "Renderer/AirspacePreviewRenderer.hpp"
 #include "Formatter/AirspaceFormatter.hpp"
-#include "Engine/Airspace/AirspaceWarningManager.hpp"
-#include "Components.hpp"
 #include "Interface.hpp"
 #include "ActionInterface.hpp"
 #include "Language/Language.hpp"
@@ -101,32 +97,34 @@ AirspaceSettingsListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc,
   PixelScalar w2 = canvas.CalcTextWidth(_("Display")) + Layout::FastScale(10);
   PixelScalar x0 = w0 - w1 - w2;
 
+  const unsigned padding = Layout::GetTextPadding();
+
   if (color_mode) {
     if (AirspacePreviewRenderer::PrepareFill(
         canvas, (AirspaceClass)i, look, renderer)) {
-      canvas.Rectangle(rc.left + x0, rc.top + Layout::FastScale(2),
-                       rc.right - Layout::FastScale(2),
-                       rc.bottom - Layout::FastScale(2));
+      canvas.Rectangle(rc.left + x0, rc.top + padding,
+                       rc.right - padding,
+                       rc.bottom - padding);
       AirspacePreviewRenderer::UnprepareFill(canvas);
     }
     if (AirspacePreviewRenderer::PrepareOutline(
         canvas, (AirspaceClass)i, look, renderer)) {
-      canvas.Rectangle(rc.left + x0, rc.top + Layout::FastScale(2),
-                       rc.right - Layout::FastScale(2),
-                       rc.bottom - Layout::FastScale(2));
+      canvas.Rectangle(rc.left + x0, rc.top + padding,
+                       rc.right - padding,
+                       rc.bottom - padding);
     }
   } else {
     if (computer.warnings.class_warnings[i])
-      canvas.DrawText(rc.left + w0 - w1 - w2, rc.top + Layout::FastScale(2),
+      canvas.DrawText(rc.left + w0 - w1 - w2, rc.top + padding,
                       _("Warn"));
 
     if (renderer.classes[i].display)
-      canvas.DrawText(rc.left + w0 - w2, rc.top + Layout::FastScale(2),
+      canvas.DrawText(rc.left + w0 - w2, rc.top + padding,
                       _("Display"));
   }
 
-  canvas.DrawClippedText(rc.left + Layout::FastScale(2),
-                         rc.top + Layout::FastScale(2),
+  canvas.DrawClippedText(rc.left + padding,
+                         rc.top + padding,
                          x0 - Layout::FastScale(10),
                          AirspaceFormatter::GetClass((AirspaceClass)i));
 }
