@@ -166,7 +166,7 @@ PlaneListWidget::CreateButtons(WidgetDialog &dialog)
   dialog.AddButton(_("New"), *this, NEW);
   edit_button = dialog.AddButton(_("Edit"), *this, EDIT);
   delete_button = dialog.AddButton(_("Delete"), *this, DELETE);
-  load_button = dialog.AddButton(_("Load"), *this, LOAD);
+  load_button = dialog.AddButton(_("Activate"), *this, LOAD);
 }
 
 void
@@ -197,15 +197,15 @@ PlaneListWidget::OnPaintItem(Canvas &canvas, const PixelRect rc, unsigned i)
   if (Profile::GetPathIsEqual("PlanePath", list[i].path)) {
     StaticString<256> buffer;
     buffer.Format(_T("%s - %s"), list[i].name.c_str(), _("Active"));
-    canvas.DrawClippedText(rc.left + Layout::FastScale(2),
-                           rc.top + Layout::FastScale(2), rc, buffer);
+    canvas.DrawClippedText(rc.left + Layout::GetTextPadding(),
+                           rc.top + Layout::GetTextPadding(), rc, buffer);
   } else
-    canvas.DrawClippedText(rc.left + Layout::FastScale(2),
-                           rc.top + Layout::FastScale(2), rc, list[i].name);
+    canvas.DrawClippedText(rc.left + Layout::GetTextPadding(),
+                           rc.top + Layout::GetTextPadding(), rc, list[i].name);
 
   canvas.Select(details_font);
 
-  canvas.DrawClippedText(rc.left + Layout::FastScale(2),
+  canvas.DrawClippedText(rc.left + Layout::GetTextPadding(),
                          rc.top + name_font.GetHeight() + Layout::FastScale(4),
                          rc, list[i].path);
 }
@@ -244,10 +244,10 @@ PlaneListWidget::LoadWithDialog(unsigned i)
   bool result = Load(i);
   if (!result) {
     title = _("Error");
-    text.Format(_("Loading of plane profile \"%s\" failed!"),
+    text.Format(_("Activating plane profile \"%s\" failed!"),
                 list[i].name.c_str());
   } else {
-    title = _("Load");
+    title = _T(" ");
     text.Format(_("Plane profile \"%s\" activated."),
                 list[i].name.c_str());
   }
@@ -269,7 +269,7 @@ PlaneListWidget::NewClicked()
 {
   Plane plane = CommonInterface::GetComputerSettings().plane;
 
-  while (dlgPlaneDetailsShowModal(UIGlobals::GetMainWindow(), plane)) {
+  while (dlgPlaneDetailsShowModal(plane)) {
     if (plane.registration.empty()) {
       ShowMessageBox(_("Please enter the registration of the plane!"),
                   _("Error"), MB_OK);
@@ -309,7 +309,7 @@ PlaneListWidget::EditClicked()
   Plane plane;
   PlaneGlue::ReadFile(plane, old_path);
 
-  while (dlgPlaneDetailsShowModal(UIGlobals::GetMainWindow(), plane)) {
+  while (dlgPlaneDetailsShowModal(plane)) {
     if (plane.registration.empty()) {
       ShowMessageBox(_("Please enter the registration of the plane!"),
                   _("Error"), MB_OK);
@@ -395,12 +395,11 @@ PlaneListWidget::OnActivateItem(unsigned i)
   assert(i < list.size());
 
   StaticString<256> tmp;
-  tmp.Format(_("Do you want to load plane profile \"%s\"?"),
+  tmp.Format(_("Do you want to activate plane profile \"%s\"?"),
              list[i].name.c_str());
 
-  if (ShowMessageBox(tmp, _("Load"), MB_YESNO) == IDYES)
-    if (LoadWithDialog(i))
-      form->SetModalResult(mrOK);
+  if (ShowMessageBox(tmp, _T(" "), MB_YESNO) == IDYES)
+    LoadWithDialog(i);
 }
 
 void
