@@ -38,6 +38,7 @@ Copyright_License {
 enum Controls {
   TASK_TYPE,
   MIN_TIME,
+  START_REQUIRES_ARM,
   START_OPEN_TIME,
   START_CLOSE_TIME,
   START_MAX_SPEED,
@@ -73,7 +74,7 @@ void
 TaskPropertiesPanel::RefreshView()
 {
   const TaskFactoryType ftype = ordered_task->GetFactoryType();
-  const OrderedTaskBehaviour &p = ordered_task->GetOrderedTaskBehaviour();
+  const OrderedTaskSettings &p = ordered_task->GetOrderedTaskSettings();
 
   const bool aat_types = ftype == TaskFactoryType::AAT ||
     ftype == TaskFactoryType::MAT;
@@ -82,6 +83,8 @@ TaskPropertiesPanel::RefreshView()
   SetRowVisible(MIN_TIME, aat_types);
   LoadValueTime(MIN_TIME, (int)p.aat_min_time);
 
+  LoadValue(START_REQUIRES_ARM, p.start_constraints.require_arm);
+
   LoadValue(START_OPEN_TIME, p.start_constraints.open_time_span.GetStart());
   LoadValue(START_CLOSE_TIME, p.start_constraints.open_time_span.GetEnd());
 
@@ -117,7 +120,7 @@ TaskPropertiesPanel::RefreshView()
 void
 TaskPropertiesPanel::ReadValues()
 {
-  OrderedTaskBehaviour p = ordered_task->GetOrderedTaskBehaviour();
+  OrderedTaskSettings p = ordered_task->GetOrderedTaskSettings();
   bool changed = false;
 
   TaskFactoryType newtype = ordered_task->GetFactoryType();
@@ -129,6 +132,9 @@ TaskPropertiesPanel::ReadValues()
     changed = true;
   }
 
+  if (SaveValue(START_REQUIRES_ARM, p.start_constraints.require_arm))
+    changed = true;
+
   RoughTime new_open = p.start_constraints.open_time_span.GetStart();
   RoughTime new_close = p.start_constraints.open_time_span.GetEnd();
   const bool start_open_modified = SaveValue(START_OPEN_TIME, new_open);
@@ -165,7 +171,7 @@ TaskPropertiesPanel::ReadValues()
                            p.finish_constraints.min_height_ref);
 
   if (changed)
-    ordered_task->SetOrderedTaskBehaviour(p);
+    ordered_task->SetOrderedTaskSettings(p);
 
   *task_changed |= changed;
 }
@@ -173,12 +179,12 @@ TaskPropertiesPanel::ReadValues()
 void
 TaskPropertiesPanel::OnFAIFinishHeightChange(DataFieldBoolean &df)
 {
-  OrderedTaskBehaviour p = ordered_task->GetOrderedTaskBehaviour();
+  OrderedTaskSettings p = ordered_task->GetOrderedTaskSettings();
   bool newvalue = df.GetAsBoolean();
   if (newvalue != p.finish_constraints.fai_finish) {
     p.finish_constraints.fai_finish = p.start_constraints.fai_finish
       = newvalue;
-    ordered_task->SetOrderedTaskBehaviour(p);
+    ordered_task->SetOrderedTaskSettings(p);
 
     *task_changed = true;
     RefreshView();
@@ -193,7 +199,6 @@ TaskPropertiesPanel::OnTaskTypeChange(DataFieldEnum &df)
   if (newtype != ordered_task->GetFactoryType()) {
     ReadValues();
     ordered_task->SetFactory(newtype);
-    ordered_task->FillMatPoints(way_points);
     *task_changed =true;
     RefreshView();
   }
@@ -211,8 +216,7 @@ TaskPropertiesPanel::OnModified(DataField &df)
 void
 TaskPropertiesPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
 {
-  DataFieldEnum *dfe = new DataFieldEnum(NULL);
-  dfe->SetListener(this);
+  DataFieldEnum *dfe = new DataFieldEnum(this);
   dfe->EnableItemHelp(true);
   const std::vector<TaskFactoryType> factory_types =
     ordered_task->GetFactoryTypes();
@@ -228,6 +232,10 @@ TaskPropertiesPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
   AddTime(_("AAT min. time"), _("Minimum AAT task time in minutes."),
           0, 36000, 60, 180);
 
+  AddBoolean(_("Arm start manually"),
+             _("Configure whether the start must be armed manually or automatically."),
+             false);
+
   const RoughTimeDelta time_zone =
     CommonInterface::GetComputerSettings().utc_offset;
   AddRoughTime(_("Start open time"), nullptr,
@@ -302,8 +310,10 @@ bool
 TaskPropertiesPanel::Leave()
 {
   ReadValues();
-  if (orig_taskType != ordered_task->GetFactoryType())
-    ordered_task->GetFactory().MutateTPsToTaskType();
+  if (orig_taskType != ordered_task->GetFactoryType()) {
+    if (ordered_task->GetFactory().MutateTPsToTaskType())
+      ordered_task->UpdateGeometry();
+  }
 
   return true;
 }
