@@ -36,8 +36,20 @@ enum class TaskFactoryType: uint8_t {
   FAI_GOAL,
   RACING,
   AAT,
+
+  /**
+   * Modified Area Task.
+   */
+  MAT,
+
   MIXED,
-  TOURING
+  TOURING,
+
+  /**
+   * This special value is used to determine the number of items
+   * above.
+   */
+  COUNT
 };
 
 #endif
