@@ -48,6 +48,9 @@ public:
 void
 UpdateInfoBoxNextDistance(InfoBoxData &data);
 
+void
+UpdateInfoBoxNextDistanceNominal(InfoBoxData &data);
+
 void
 UpdateInfoBoxNextETE(InfoBoxData &data);
 
@@ -96,6 +99,9 @@ UpdateInfoBoxTaskSpeedAchieved(InfoBoxData &data);
 void
 UpdateInfoBoxTaskSpeedInstant(InfoBoxData &data);
 
+void
+UpdateInfoBoxTaskSpeedHour(InfoBoxData &data);
+
 void
 UpdateInfoBoxTaskAATime(InfoBoxData &data);
 
