@@ -22,10 +22,10 @@ Copyright_License {
 */
 
 #include "NOAALook.hpp"
-#include "resource.h"
+#include "Resources.hpp"
 
 void
 NOAALook::Initialise()
 {
-  icon.Load(IDB_WEATHER_STATION, IDB_WEATHER_STATION_HD);
+  icon.LoadResource(IDB_WEATHER_STATION, IDB_WEATHER_STATION_HD);
 }
