@@ -33,10 +33,11 @@ Copyright_License {
 
 static void
 RenderFAISectors(Canvas &canvas, const WindowProjection &projection,
-                 const GeoPoint &a, const GeoPoint &b)
+                 const GeoPoint &a, const GeoPoint &b,
+                 const FAITriangleSettings &settings)
 {
-  RenderFAISector(canvas, projection, a, b, false);
-  RenderFAISector(canvas, projection, a, b, true);
+  RenderFAISector(canvas, projection, a, b, false, settings);
+  RenderFAISector(canvas, projection, a, b, true, settings);
 }
 
 void
@@ -46,16 +47,21 @@ MapWindow::DrawContest(Canvas &canvas)
 
   if (GetMapSettings().show_fai_triangle_areas &&
       flying.release_location.IsValid() && flying.far_location.IsValid()) {
+    const FAITriangleSettings &settings =
+      GetMapSettings().fai_triangle_settings;
+
     /* draw FAI triangle areas */
     static constexpr Color fill_color = COLOR_YELLOW;
+#if defined(ENABLE_OPENGL) || defined(USE_MEMORY_CANVAS)
 #ifdef ENABLE_OPENGL
-    GLEnable blend(GL_BLEND);
-    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+#endif
     canvas.Select(Brush(fill_color.WithAlpha(60)));
     canvas.Select(Pen(1, COLOR_BLACK.WithAlpha(90)));
 
     RenderFAISectors(canvas, render_projection,
-                     flying.release_location, flying.far_location);
+                     flying.release_location, flying.far_location,
+                     settings);
 #else
     BufferCanvas buffer_canvas;
     buffer_canvas.Create(canvas);
@@ -67,15 +73,11 @@ MapWindow::DrawContest(Canvas &canvas)
 #else
     buffer_canvas.Select(Brush(fill_color));
 #endif
-    buffer_canvas.SelectNullPen();
+    buffer_canvas.SelectBlackPen();
     RenderFAISectors(buffer_canvas, render_projection,
-                     flying.release_location, flying.far_location);
+                     flying.release_location, flying.far_location,
+                     settings);
     canvas.CopyAnd(buffer_canvas);
-
-    canvas.SelectHollowBrush();
-    canvas.SelectBlackPen();
-    RenderFAISectors(canvas, render_projection,
-                     flying.release_location, flying.far_location);
 #endif
   }
 }
