@@ -26,6 +26,7 @@ Copyright_License {
 
 #include "DebugReplay.hpp"
 #include "Device/Parser.hpp"
+#include "Time/ReplayClock.hpp"
 
 #include <memory>
 
@@ -38,6 +39,8 @@ class DebugReplayNMEA : public DebugReplay {
 
   NMEAParser parser;
 
+  ReplayClock clock;
+
 public:
   DebugReplayNMEA(NLineReader *reader, const DeviceRegister *driver);
 
