@@ -29,10 +29,10 @@ Copyright_License {
 #include "Device/Register.hpp"
 #include "Device/Parser.hpp"
 #include "Device/device.hpp"
+#include "Device/Config.hpp"
 #include "Engine/Waypoint/Waypoints.hpp"
 #include "OS/Args.hpp"
 #include "Operation/ConsoleOperationEnvironment.hpp"
-#include "Profile/DeviceConfig.hpp"
 #include "IO/Async/GlobalIOThread.hpp"
 #include "Util/ConvertString.hpp"
 
@@ -51,16 +51,16 @@ NMEAParser::ReadDate(NMEAInputLine &line, BrokenDate &date)
 }
 
 bool
-NMEAParser::TimeHasAdvanced(fixed this_time, fixed &last_time, NMEAInfo &info)
+NMEAParser::ReadTime(NMEAInputLine &line, BrokenTime &broken_time,
+                     fixed &time_of_day_s)
 {
   return false;
 }
 
-fixed
-NMEAParser::TimeModify(fixed fix_time, BrokenDateTime &date_time,
-                       bool date_available)
+bool
+NMEAParser::TimeHasAdvanced(fixed this_time, fixed &last_time, NMEAInfo &info)
 {
-  return fixed(0);
+  return false;
 }
 
 /*
@@ -110,6 +110,13 @@ int main(int argc, char **argv)
     return EXIT_FAILURE;
   }
 
+  if (!port->WaitConnected(env)) {
+    delete port;
+    DeinitialiseIOThread();
+    fprintf(stderr, "Failed to connect the port\n");
+    return EXIT_FAILURE;
+  }
+
   Device *device = driver->CreateOnPort(config, *port);
   assert(device != NULL);
 
